==> openGion6.2.6.0_dev.zip: uap/webapps/gf/db/hsql/sql/install/02_INDEX/AllDropC.sql <==

ALTER TABLE BONUS DROP CONSTRAINT BONUS_UQ;
ALTER TABLE DEPT DROP CONSTRAINT DEPT_UQ;
DROP INDEX DEPT_SA;
ALTER TABLE EMP DROP CONSTRAINT EMP_UQ;
DROP INDEX EMP_SB;
ALTER TABLE GF01 DROP CONSTRAINT GF01_UQ;
ALTER TABLE GF01 DROP CONSTRAINT GF01_LUQ;
DROP INDEX GF01_SA;
ALTER TABLE GF02 DROP CONSTRAINT GF02_UQ;
ALTER TABLE GF02 DROP CONSTRAINT GF02_LUQ;
DROP INDEX GF02_SA;
ALTER TABLE GF03 DROP CONSTRAINT GF03_UQ;
ALTER TABLE GF03 DROP CONSTRAINT GF03_LUQ;
ALTER TABLE GF05 DROP CONSTRAINT GF05_UQ;
ALTER TABLE GF05 DROP CONSTRAINT GF05_LUQ;
DROP INDEX GF05_SA;
ALTER TABLE GF06 DROP CONSTRAINT GF06_UQ;
ALTER TABLE GF06 DROP CONSTRAINT GF06_LUQ;
ALTER TABLE GF07 DROP CONSTRAINT GF07_UQ;
ALTER TABLE GF07 DROP CONSTRAINT GF07_LUQ;
DROP INDEX GF07_SA;
ALTER TABLE GF09 DROP CONSTRAINT GF09_UQ;
ALTER TABLE GF09 DROP CONSTRAINT GF09_LUQ;
ALTER TABLE GF13 DROP CONSTRAINT GF13_UQ;
ALTER TABLE GF13 DROP CONSTRAINT GF13_LUQ;
ALTER TABLE GF19 DROP CONSTRAINT GF19_UQ;
ALTER TABLE GF19 DROP CONSTRAINT GF19_LUQ;
ALTER TABLE GF21 DROP CONSTRAINT GF21_UQ;
ALTER TABLE GF21 DROP CONSTRAINT GF21_LUQ;
DROP INDEX GF21_SA;
ALTER TABLE GF22 DROP CONSTRAINT GF22_UQ;
ALTER TABLE GF22 DROP CONSTRAINT GF22_LUQ;
DROP INDEX GF22_SA;
ALTER TABLE GF23 DROP CONSTRAINT GF23_UQ;
ALTER TABLE GF23 DROP CONSTRAINT GF23_LUQ;
ALTER TABLE GF24 DROP CONSTRAINT GF24_UQ;
ALTER TABLE GF24 DROP CONSTRAINT GF24_LUQ;
ALTER TABLE GF25 DROP CONSTRAINT GF25_UQ;
ALTER TABLE GF25 DROP CONSTRAINT GF25_LUQ;
DROP INDEX GF25_SA;
ALTER TABLE GF27 DROP CONSTRAINT GF27_UQ;
ALTER TABLE GF27 DROP CONSTRAINT GF27_LUQ;
DROP INDEX GF27_SA;
DROP INDEX GF27_SB;
DROP INDEX GF27_SC;
ALTER TABLE GF28 DROP CONSTRAINT GF28_UQ;
DROP INDEX GF28_SA;
DROP INDEX GF28_SB;
DROP INDEX GF28_SC;
ALTER TABLE GF41 DROP CONSTRAINT GF41_UQ;
ALTER TABLE GF41 DROP CONSTRAINT GF41_LUQ;
ALTER TABLE GF42 DROP CONSTRAINT GF42_LUQ;
DROP INDEX GF42_SA;
DROP INDEX GF42_SB;
DROP INDEX GF42_SC;
DROP INDEX GF42_SD;
DROP INDEX GF42_SE;
DROP INDEX GF42_SF;
ALTER TABLE GF43 DROP CONSTRAINT GF43_UQ;
DROP INDEX GF43_SA;
ALTER TABLE GF44 DROP CONSTRAINT GF44_UQ;
ALTER TABLE GF44 DROP CONSTRAINT GF44_LUQ;
ALTER TABLE GF45 DROP CONSTRAINT GF45_UQ;
ALTER TABLE GF45 DROP CONSTRAINT GF45_LUQ;
ALTER TABLE GF46 DROP CONSTRAINT GF46_UQ;
ALTER TABLE GF46 DROP CONSTRAINT GF46_LUQ;
ALTER TABLE GF60 DROP CONSTRAINT GF60_UQ;
ALTER TABLE GF60 DROP CONSTRAINT GF60_LUQ;
DROP INDEX GF60_SA;
DROP INDEX GF60_SB;
ALTER TABLE GF61 DROP CONSTRAINT GF61_UQ;
ALTER TABLE GF61 DROP CONSTRAINT GF61_LUQ;
DROP INDEX GF61_SA;
ALTER TABLE GF62 DROP CONSTRAINT GF62_UQ;
ALTER TABLE GF62 DROP CONSTRAINT GF62_LUQ;
DROP INDEX GF62_SA;
DROP INDEX GF62_SB;
ALTER TABLE GF63 DROP CONSTRAINT GF63_UQ;
ALTER TABLE GF63 DROP CONSTRAINT GF63_LUQ;
DROP INDEX GF63_SA;
ALTER TABLE GF64 DROP CONSTRAINT GF64_UQ;
ALTER TABLE GF64 DROP CONSTRAINT GF64_LUQ;
DROP INDEX GF64_SA;
ALTER TABLE GF65 DROP CONSTRAINT GF65_UQ;
ALTER TABLE GF65 DROP CONSTRAINT GF65_LUQ;
DROP INDEX GF65_SA;
ALTER TABLE GF66 DROP CONSTRAINT GF66_UQ;
ALTER TABLE GF66 DROP CONSTRAINT GF66_LUQ;
DROP INDEX GF66_SA;
ALTER TABLE GF67 DROP CONSTRAINT GF67_UQ;
ALTER TABLE GF67 DROP CONSTRAINT GF67_LUQ;
ALTER TABLE GF68 DROP CONSTRAINT GF68_UQ;
ALTER TABLE GF68 DROP CONSTRAINT GF68_LUQ;
ALTER TABLE GF69 DROP CONSTRAINT GF69_UQ;
ALTER TABLE GF69 DROP CONSTRAINT GF69_LUQ;
DROP INDEX GF69_SA;
DROP INDEX GF69_SC;
ALTER TABLE GF70 DROP CONSTRAINT GF70_UQ;
DROP INDEX GF70_SA;
DROP INDEX GF70_SB;
DROP INDEX GF70_SC;
ALTER TABLE GF71 DROP CONSTRAINT GF71_UQ;
DROP INDEX GF71_SA;
DROP INDEX GF71_SB;
DROP INDEX GF71_SC;
ALTER TABLE GF72 DROP CONSTRAINT GF72_UQ;
DROP INDEX GF72_SA;
DROP INDEX GF72_SB;
DROP INDEX GF72_SC;
ALTER TABLE GF73 DROP CONSTRAINT GF73_UQ;
DROP INDEX GF73_SA;
DROP INDEX GF73_SB;
DROP INDEX GF73_SC;
ALTER TABLE GF74 DROP CONSTRAINT GF74_UQ;
DROP INDEX GF74_SA;
DROP INDEX GF74_SB;
ALTER TABLE GF75 DROP CONSTRAINT GF75_UQ;
DROP INDEX GF75_SA;
DROP INDEX GF75_SB;
DROP INDEX GF75_SC;
ALTER TABLE GF76 DROP CONSTRAINT GF76_UQ;
DROP INDEX GF76_SA;
DROP INDEX GF76_SB;
ALTER TABLE GF77 DROP CONSTRAINT GF77_UQ;
DROP INDEX GF77_SA;
DROP INDEX GF77_SB;
DROP INDEX GF77_SC;
ALTER TABLE GF78 DROP CONSTRAINT GF78_UQ;
ALTER TABLE GF78 DROP CONSTRAINT GF78_LUQ;
DROP INDEX GF78_SA;
DROP INDEX GF78_SB;
ALTER TABLE GF80 DROP CONSTRAINT GF80_UQ;
ALTER TABLE GF80 DROP CONSTRAINT GF80_LUQ;
DROP INDEX GF80_SA;
ALTER TABLE GF81 DROP CONSTRAINT GF81_UQ;
ALTER TABLE GF81 DROP CONSTRAINT GF81_LUQ;
DROP INDEX GF81_SA;
ALTER TABLE GF82 DROP CONSTRAINT GF82_UQ;
ALTER TABLE GF82 DROP CONSTRAINT GF82_LUQ;
ALTER TABLE GF83 DROP CONSTRAINT GF83_UQ;
DROP INDEX GF83_SA;
ALTER TABLE GF84 DROP CONSTRAINT GF84_UQ;
ALTER TABLE GF84 DROP CONSTRAINT GF84_LUQ;
DROP INDEX GF84_SA;
DROP INDEX GF84_SB;
ALTER TABLE GF85 DROP CONSTRAINT GF85_UQ;
ALTER TABLE GF85 DROP CONSTRAINT GF85_LUQ;
DROP INDEX GF85_SA;
DROP INDEX GF85_SB;
ALTER TABLE GF90 DROP CONSTRAINT GF90_UQ;
ALTER TABLE GF90 DROP CONSTRAINT GF90_LUQ;
DROP INDEX GF90_SA;
DROP INDEX GF90_SB;
DROP INDEX GF90_SC;
DROP INDEX GF90_SD;
DROP INDEX GF90_SE;
ALTER TABLE GF91 DROP CONSTRAINT GF91_UQ;
ALTER TABLE GF91 DROP CONSTRAINT GF91_LUQ;
DROP INDEX GF91_SA;
ALTER TABLE GF92 DROP CONSTRAINT GF92_UQ;
ALTER TABLE GF92 DROP CONSTRAINT GF92_LUQ;
DROP INDEX GF92_SA;
DROP INDEX GF92_SB;
DROP INDEX GF92_SC;
ALTER TABLE GF93 DROP CONSTRAINT GF93_UQ;
DROP INDEX GF93_SA;
ALTER TABLE GF94 DROP CONSTRAINT GF94_UQ;
DROP INDEX GF94_SA;
DROP INDEX GF94_SB;
ALTER TABLE GF95 DROP CONSTRAINT GF95_UQ;
ALTER TABLE GF95 DROP CONSTRAINT GF95_LUQ;
DROP INDEX GF95_SA;
ALTER TABLE GF96 DROP CONSTRAINT GF96_UQ;
ALTER TABLE GF96 DROP CONSTRAINT GF96_LUQ;
DROP INDEX GF96_SA;
DROP INDEX GF96_SB;
DROP INDEX GF96_SC;
ALTER TABLE GFW41 DROP CONSTRAINT GFW41_UQ;
ALTER TABLE GFW41 DROP CONSTRAINT GFW41_LUQ;
ALTER TABLE GFX01 DROP CONSTRAINT GFX01_LUQ;
ALTER TABLE GFX02 DROP CONSTRAINT GFX02_LUQ;

==> openGion6.4.1.0_dev.zip: uap/webapps/gf/db/hsql/sql/install/02_INDEX/AllDropC.sql <==

ALTER TABLE BONUS DROP CONSTRAINT BONUS_UQ;
ALTER TABLE DEPT DROP CONSTRAINT DEPT_UQ;
DROP INDEX DEPT_SA;
ALTER TABLE EMP DROP CONSTRAINT EMP_UQ;
DROP INDEX EMP_SB;
ALTER TABLE GF01 DROP CONSTRAINT GF01_UQ;
ALTER TABLE GF01 DROP CONSTRAINT GF01_LUQ;
DROP INDEX GF01_SA;
ALTER TABLE GF02 DROP CONSTRAINT GF02_UQ;
ALTER TABLE GF02 DROP CONSTRAINT GF02_LUQ;
DROP INDEX GF02_SA;
ALTER TABLE GF03 DROP CONSTRAINT GF03_UQ;
ALTER TABLE GF03 DROP CONSTRAINT GF03_LUQ;
ALTER TABLE GF05 DROP CONSTRAINT GF05_UQ;
ALTER TABLE GF05 DROP CONSTRAINT GF05_LUQ;
DROP INDEX GF05_SA;
ALTER TABLE GF06 DROP CONSTRAINT GF06_UQ;
ALTER TABLE GF06 DROP CONSTRAINT GF06_LUQ;
ALTER TABLE GF07 DROP CONSTRAINT GF07_UQ;
ALTER TABLE GF07 DROP CONSTRAINT GF07_LUQ;
DROP INDEX GF07_SA;
ALTER TABLE GF09 DROP CONSTRAINT GF09_UQ;
ALTER TABLE GF09 DROP CONSTRAINT GF09_LUQ;
ALTER TABLE GF13 DROP CONSTRAINT GF13_UQ;
ALTER TABLE GF13 DROP CONSTRAINT GF13_LUQ;
ALTER TABLE GF19 DROP CONSTRAINT GF19_UQ;
ALTER TABLE GF19 DROP CONSTRAINT GF19_LUQ;
ALTER TABLE GF21 DROP CONSTRAINT GF21_UQ;
ALTER TABLE GF21 DROP CONSTRAINT GF21_LUQ;
DROP INDEX GF21_SA;
ALTER TABLE GF22 DROP CONSTRAINT GF22_UQ;
ALTER TABLE GF22 DROP CONSTRAINT GF22_LUQ;
DROP INDEX GF22_SA;
ALTER TABLE GF23 DROP CONSTRAINT GF23_UQ;
ALTER TABLE GF23 DROP CONSTRAINT GF23_LUQ;
ALTER TABLE GF24 DROP CONSTRAINT GF24_UQ;
ALTER TABLE GF24 DROP CONSTRAINT GF24_LUQ;
ALTER TABLE GF25 DROP CONSTRAINT GF25_UQ;
ALTER TABLE GF25 DROP CONSTRAINT GF25_LUQ;
DROP INDEX GF25_SA;
ALTER TABLE GF27 DROP CONSTRAINT GF27_UQ;
ALTER TABLE GF27 DROP CONSTRAINT GF27_LUQ;
DROP INDEX GF27_SA;
DROP INDEX GF27_SB;
DROP INDEX GF27_SC;
ALTER TABLE GF28 DROP CONSTRAINT GF28_UQ;
DROP INDEX GF28_SA;
DROP INDEX GF28_SB;
DROP INDEX GF28_SC;
ALTER TABLE GF41 DROP CONSTRAINT GF41_UQ;
ALTER TABLE GF41 DROP CONSTRAINT GF41_LUQ;
ALTER TABLE GF42 DROP CONSTRAINT GF42_LUQ;
DROP INDEX GF42_SA;
DROP INDEX GF42_SB;
DROP INDEX GF42_SC;
DROP INDEX GF42_SD;
DROP INDEX GF42_SE;
DROP INDEX GF42_SF;
ALTER TABLE GF43 DROP CONSTRAINT GF43_UQ;
DROP INDEX GF43_SA;
ALTER TABLE GF44 DROP CONSTRAINT GF44_UQ;
ALTER TABLE GF44 DROP CONSTRAINT GF44_LUQ;
ALTER TABLE GF45 DROP CONSTRAINT GF45_UQ;
ALTER TABLE GF45 DROP CONSTRAINT GF45_LUQ;
ALTER TABLE GF46 DROP CONSTRAINT GF46_UQ;
ALTER TABLE GF46 DROP CONSTRAINT GF46_LUQ;
DROP INDEX GF46_SA;
DROP INDEX GF46_SB;
ALTER TABLE GF60 DROP CONSTRAINT GF60_UQ;
ALTER TABLE GF60 DROP CONSTRAINT GF60_LUQ;
DROP INDEX GF60_SA;
DROP INDEX GF60_SB;
ALTER TABLE GF61 DROP CONSTRAINT GF61_UQ;
ALTER TABLE GF61 DROP CONSTRAINT GF61_LUQ;
DROP INDEX GF61_SA;
ALTER TABLE GF62 DROP CONSTRAINT GF62_UQ;
ALTER TABLE GF62 DROP CONSTRAINT GF62_LUQ;
DROP INDEX GF62_SA;
DROP INDEX GF62_SB;
ALTER TABLE GF63 DROP CONSTRAINT GF63_UQ;
ALTER TABLE GF63 DROP CONSTRAINT GF63_LUQ;
DROP INDEX GF63_SA;
ALTER TABLE GF64 DROP CONSTRAINT GF64_UQ;
ALTER TABLE GF64 DROP CONSTRAINT GF64_LUQ;
DROP INDEX GF64_SA;
ALTER TABLE GF65 DROP CONSTRAINT GF65_UQ;
ALTER TABLE GF65 DROP CONSTRAINT GF65_LUQ;
DROP INDEX GF65_SA;
ALTER TABLE GF66 DROP CONSTRAINT GF66_UQ;
ALTER TABLE GF66 DROP CONSTRAINT GF66_LUQ;
DROP INDEX GF66_SA;
ALTER TABLE GF67 DROP CONSTRAINT GF67_UQ;
ALTER TABLE GF67 DROP CONSTRAINT GF67_LUQ;
ALTER TABLE GF68 DROP CONSTRAINT GF68_UQ;
ALTER TABLE GF68 DROP CONSTRAINT GF68_LUQ;
ALTER TABLE GF69 DROP CONSTRAINT GF69_UQ;
ALTER TABLE GF69 DROP CONSTRAINT GF69_LUQ;
DROP INDEX GF69_SA;
DROP INDEX GF69_SC;
ALTER TABLE GF70 DROP CONSTRAINT GF70_UQ;
DROP INDEX GF70_SA;
DROP INDEX GF70_SB;
DROP INDEX GF70_SC;
ALTER TABLE GF71 DROP CONSTRAINT GF71_UQ;
DROP INDEX GF71_SA;
DROP INDEX GF71_SB;
DROP INDEX GF71_SC;
ALTER TABLE GF72 DROP CONSTRAINT GF72_UQ;
DROP INDEX GF72_SA;
DROP INDEX GF72_SB;
DROP INDEX GF72_SC;
ALTER TABLE GF73 DROP CONSTRAINT GF73_UQ;
DROP INDEX GF73_SA;
DROP INDEX GF73_SB;
DROP INDEX GF73_SC;
ALTER TABLE GF74 DROP CONSTRAINT GF74_UQ;
DROP INDEX GF74_SA;
DROP INDEX GF74_SB;
ALTER TABLE GF75 DROP CONSTRAINT GF75_UQ;
DROP INDEX GF75_SA;
DROP INDEX GF75_SB;
DROP INDEX GF75_SC;
ALTER TABLE GF76 DROP CONSTRAINT GF76_UQ;
DROP INDEX GF76_SA;
DROP INDEX GF76_SB;
ALTER TABLE GF77 DROP CONSTRAINT GF77_UQ;
DROP INDEX GF77_SA;
DROP INDEX GF77_SB;
DROP INDEX GF77_SC;
ALTER TABLE GF78 DROP CONSTRAINT GF78_UQ;
ALTER TABLE GF78 DROP CONSTRAINT GF78_LUQ;
DROP INDEX GF78_SA;
DROP INDEX GF78_SB;
ALTER TABLE GF80 DROP CONSTRAINT GF80_UQ;
ALTER TABLE GF80 DROP CONSTRAINT GF80_LUQ;
DROP INDEX GF80_SA;
ALTER TABLE GF81 DROP CONSTRAINT GF81_UQ;
ALTER TABLE GF81 DROP CONSTRAINT GF81_LUQ;
DROP INDEX GF81_SA;
ALTER TABLE GF82 DROP CONSTRAINT GF82_UQ;
ALTER TABLE GF82 DROP CONSTRAINT GF82_LUQ;
ALTER TABLE GF83 DROP CONSTRAINT GF83_UQ;
DROP INDEX GF83_SA;
ALTER TABLE GF84 DROP CONSTRAINT GF84_UQ;
ALTER TABLE GF84 DROP CONSTRAINT GF84_LUQ;
DROP INDEX GF84_SA;
DROP INDEX GF84_SB;
ALTER TABLE GF85 DROP CONSTRAINT GF85_UQ;
ALTER TABLE GF85 DROP CONSTRAINT GF85_LUQ;
DROP INDEX GF85_SA;
DROP INDEX GF85_SB;
ALTER TABLE GF90 DROP CONSTRAINT GF90_UQ;
ALTER TABLE GF90 DROP CONSTRAINT GF90_LUQ;
DROP INDEX GF90_SA;
DROP INDEX GF90_SB;
DROP INDEX GF90_SC;
DROP INDEX GF90_SD;
DROP INDEX GF90_SE;
ALTER TABLE GF91 DROP CONSTRAINT GF91_UQ;
ALTER TABLE GF91 DROP CONSTRAINT GF91_LUQ;
DROP INDEX GF91_SA;
ALTER TABLE GF92 DROP CONSTRAINT GF92_UQ;
ALTER TABLE GF92 DROP CONSTRAINT GF92_LUQ;
DROP INDEX GF92_SA;
DROP INDEX GF92_SB;
DROP INDEX GF92_SC;
ALTER TABLE GF93 DROP CONSTRAINT GF93_UQ;
DROP INDEX GF93_SA;
ALTER TABLE GF94 DROP CONSTRAINT GF94_UQ;
DROP INDEX GF94_SA;
DROP INDEX GF94_SB;
ALTER TABLE GF95 DROP CONSTRAINT GF95_UQ;
ALTER TABLE GF95 DROP CONSTRAINT GF95_LUQ;
DROP INDEX GF95_SA;
ALTER TABLE GF96 DROP CONSTRAINT GF96_UQ;
ALTER TABLE GF96 DROP CONSTRAINT GF96_LUQ;
DROP INDEX GF96_SA;
DROP INDEX GF96_SB;
DROP INDEX GF96_SC;
